@@ -971,6 +971,7 @@ class DSLibrary(object):
                     def __init__(self, stream, iterator):
                         self.stream = stream
                         self.iterator = iterator
+                        self.closed = False
 
                     def __iter__(self):
                         return self
@@ -979,22 +980,36 @@ class DSLibrary(object):
                         try:
                             return next(self.iterator)
                         except StopIteration:
-                            self.stream.close()
+                            self.close()
                             raise
 
+                    def close(self):
+                        if not self.closed:
+                            self.stream.close()
+                            self.closed = True
+
                     def tell(self):
                         if not hasattr(self.stream, "tell"):
                             return
                         return self.stream.tell()
+
+                    def get_chunk(self, size=None):
+                        try:
+                            if hasattr(self.iterator, "get_chunk"):
+                                return self.iterator.get_chunk(size)
+                        except StopIteration:
+                            self.close()
+                            raise
+
                 stream = use_opener(uri, mode='rb', **open_args)
-                iterator = self._open_from_stream(stream, read_method, read_args)
+                iterator = self._open_from_stream(stream, read_method, read_args, format)
                 return CloseAfterIteration(stream, iterator)
             with use_opener(uri, mode='rb', **open_args) as f_r:
-                return self._open_from_stream(f_r, read_method, read_args)
+                return self._open_from_stream(f_r, read_method, read_args, format)
         # TODO support read from folder, i.e. folder of CSVs, parquet, etc.
         raise DSLibraryException(f"file type not supported: {format}")
 
-    def _open_from_stream(self, f_r, read_method, read_args):
+    def _open_from_stream(self, f_r, read_method, read_args, format):
         if format == "xlsx" and not f_r.seekable():
             # the XLSX reader requires its stream to be seekable so we download to a temporary file
             with tempfile.NamedTemporaryFile(mode='wb') as f_tmp:
